<?php

namespace Drupal\unique_alias_checker\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;

/**
 * Configure Unique Alias Checker settings.
 */
class UniqueAliasCheckerSettingsForm extends ConfigFormBase implements ContainerInjectionInterface {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'unique_alias_checker_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'unique_alias_checker.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $settings = $this->config('unique_alias_checker.settings');

    if ($settings->get('error_msg')) {
      $default_error_msg = $settings->get('error_msg');
    }
    else {
      $default_error_msg = 'The URL that would be generated with this content is already in use. Please update the content to generate a new URL alias.';
    }

    $form['unique_alias_checker_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#open' => TRUE,
      'error_msg' => [
        '#type' => 'textarea',
        '#title' => $this->t('Error Message'),
        '#description' => $this->t('Change this text to customize the error message to be 
        displayed when a duplicate alias is detected.'),
        '#default_value' => $default_error_msg,
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->config('unique_alias_checker.settings');

    $config
      ->set('error_msg', $form_state->getValue('error_msg'))
      ->save();
  }

}
